<?php


namespace Schaffen\Core\Person\Services;

use Schaffen\Core\User\Repositories\UserRepository;
use Schaffen\Financial\BillingRoute\Models\SalesmanRoute;
use Schaffen\Financial\BillingRoute\Repositories\SalesmanRouteRepository;


class ClientServices
{

    public function validateClient($values){

        $response =  [
            'status_code' => null,
            'messages' => [],
            'client' => null
        ];

        if($values['pes_nome'] == "" || $values['pes_nome'] == null){
            $response['messages'][]= "O nome do cliente é obrigatório";
            $response['status_code'] = 500;

        }
        if($values['pes_identificador'] == "" || $values['pes_identificador'] == null){
            $response['messages'][]= "O identificador do cliente é obrigatório";
            $response['status_code'] = 500;
        }
        return $response;
    }



    public function getUser($values)
    {
        $user_repository = app()->make(UserRepository::class);
        $user = $user_repository->first(['usu_codigo' => $values['user']]);
        return $user['usu_nome'];
    }


    public function setAddress($values, $pes_codigo)
    {
        $values['address']['pee_fk_pes_codigo'] = $pes_codigo;
        $values['address']['pee_padrao'] = 1;
        $values['address']['pee_user_insert'] = $values['pes_user_insert'];
        $values['address']['pee_cep'] = $this->limpaCEP($values['address']['pee_cep']);
        return $values['address'];
    }

    public function setContact($values, $pes_codigo)
    {
        $values['contact']['peco_fk_pes_codigo'] = $pes_codigo;
        $values['contact']['peco_padrao'] = 1;
        $values['contact']['peco_user_insert'] = $values['pes_user_insert'];
        return $values['contact'];
    }


    public function getRotaVendedor($values)
    {
        $salesman_route_repository = app()->make(SalesmanRouteRepository::class);
        $salesman_route = $values['roc_fk_rot_codigo'];
        if($salesman_route == null){
            $salesman_route = $salesman_route_repository->first(['rov_fk_pes_codigo' => $values['person']])->rov_fk_rot_codigo;
        }
        return $salesman_route;
    }

    function limpaCPF_CNPJ($valor)
    {
        $valor = trim($valor);
        $valor = str_replace(".", "", $valor);
        $valor = str_replace(",", "", $valor);
        $valor = str_replace("-", "", $valor);
        $valor = str_replace("/", "", $valor);
        return $valor;
    }

    function limpaCEP($valor)
    {
        $valor = trim($valor);
        $valor = str_replace(".", "", $valor);
        $valor = str_replace(",", "", $valor);
        $valor = str_replace("-", "", $valor);
        $valor = str_replace("/", "", $valor);
        return $valor;
    }

    public function getPersonModality($values, $pes_codigo)
    {
        $pm = [
            "pem_fk_pes_codigo" => $pes_codigo,
            "pem_fk_mdd_codigo" => 3,
            "pem_status" => 1,
            "pem_user_insert" => $values['pes_user_insert'],

        ];
        return $pm;
    }

    public function setClientRoute($values, $rota_do_vendedor, $pes_codigo_cliente)
    {

        if($values['roc_fk_rot_codigo'] == "" || $values['roc_fk_rot_codigo'] == null){
            $values['roc_fk_rot_codigo'] = $rota_do_vendedor;
        }
        return [
            'roc_fk_pes_codigo' => $pes_codigo_cliente,
            'roc_fk_rot_codigo' => $rota_do_vendedor
        ];

    }

    public  function  setPersonBranch($values, $pes_codigo_cliente){
        return [

            'pef_fk_fil_codigo' => $values['fun_fk_fil_codigo'],
            'pef_fk_pes_codigo' => $pes_codigo_cliente
        ];
    }
}