<?php


namespace Schaffen\Core\Product\Repositories;

use Freelabois\LaravelQuickstart\Extendables\Repository;
use Schaffen\Core\Product\Models\ProductVarietyPack;

class ProductVarietyPackRepository extends Repository
{
    protected $model = ProductVarietyPack::class;

    protected $searchableFields = [
        ["field" => 'pes_status'],
        ["field" => 'pve_codigo'],
        ["field" => 'pve_codigo_referencia'],
        ["field" => 'pve_codigo_barras']
    ];

    public function injectFiltersOnQuery()
    {
        $serial = NULL;
        $precisa_de_usuario = NULL;
        $only_service = NULL;
        $only_active = NULL;
        $product_complete_name = NULL;
        
        // composition
        $composition = NULL;
        $composition_filters = [];

        extract($this->filters);

        $this->query->when($serial, function ($query) use ($serial) {
            return $query->whereHas('employee.mobile', function ($query) use ($serial) {
                return $query->where('fum_serial', $serial)
                    ->whereNull('fum_bloqueado')
                    ->where('fum_libera_manutencao', 1);
            });
        });

        $this->query->when($precisa_de_usuario, function ($query) {
            return $query->whereHas('users');
        });

        $this->query->when($only_service, function ($query) use ($only_service) {
            return $query->whereHas('product_variety.product', function ($query) use ($only_service) {
                if (is_bool($only_service) ? $only_service : $only_service == "true") {
                    $query->where("pro_servico", 1);
                }
                return $query;
            });
        });

        $this->query->when($only_active, function ($query) use ($only_active) {
            return $query->whereHas('product_variety.product', function ($query) use ($only_active) {
                if (is_bool($only_active) ? $only_active : $only_active == "true") {
                    $query->where("pro_status", 1);
                }
                return $query;
            });
        });


        //commit
        $this->query->when($product_complete_name, function ($query) use ($product_complete_name) {
            $field = "pro_descricao||' - '||prv_descricao||' - '||unm_descricao";
            $field .= " || case when trim(pve_codigo_barras) <> '' then ' - ('||pve_codigo_barras||')' else '' end";
            $field .= " || case when mar_codigo <> '-1' then' - '||mar_descricao||'' else '' end";
            return $query->whereRaw("{$field} ilike '%{$product_complete_name}%' ");
        });

        //composition
        $this->query->when($composition, function ($query) use ($composition_filters) {
            $initial_date = NULL;
            $final_date = NULL;
            $pcp_fk_pve_codigo_acabado = NULL;

            extract($composition_filters);

            // deve ser filtrada do historico pq a edição resseta a data de criação das composições
            $query->when($initial_date, function ($query) use ($initial_date) {
                $query->whereHas('compositionHistoric', function($query) use ($initial_date) {
                    return $query->where('pch_operacao', 'CADASTRO_PCP')
                    ->where('created_at', '>=', $initial_date);
                });
            });

            $query->when($final_date, function ($query) use ($final_date) {
                $query->whereHas('compositionHistoric', function($query) use ($final_date) {
                    return $query->where('pch_operacao', 'CADASTRO_PCP')
                        ->where('created_at', '<=', $final_date);
                });
            });

            $query->when($pcp_fk_pve_codigo_acabado, function ($query) use ($pcp_fk_pve_codigo_acabado) {
                return $query->where('pve_codigo', $pcp_fk_pve_codigo_acabado);
            });

            $query->whereHas('composition', function ($query) use ($composition_filters) {
                $pcp_fk_pve_codigo_materia_prima = NULL;
                $usu_nome = NULL;
                $control_wharehouse  = NULL;

                extract($composition_filters);
                
                $query->when($pcp_fk_pve_codigo_materia_prima, function ($query) use ($pcp_fk_pve_codigo_materia_prima) {
                    return $query->where('pcp_fk_pve_codigo_materia_prima', $pcp_fk_pve_codigo_materia_prima);
                });
                
                $query->when($usu_nome, function ($query) use ($usu_nome) {
                    $query->where('created_by', $usu_nome);
                });
                
                $query->when(isset($control_wharehouse), function ($query) use ($control_wharehouse) {
                    $query->where('pcp_controla_estoque', $control_wharehouse);
                });

                return $query;
            });

            $query->with(['composition' => function ($query) {
                return $query->withCount(['production_order as production_orders_open_count' => function ($query) {
                    return $query->whereHas('status', function ($query) {
                        $query->where('st_controla_estoque', 1);
                    });
                }]);
            }]);
        });

        parent::injectFiltersOnQuery();
    }
}
